@@ -11,7 +11,7 @@ from cobra.mit.request import ConfigRequest
 from cobra.model.fv import Tenant
 from cobra.internal.codec.xmlcodec import toXMLStr
 import os
-# from IPython import embed
+from IPython import embed
 
 
 def null_function():
